@@ -5,8 +5,8 @@
 #' both have download methods, to downloads package files into a
 #' configured directory (see ['Configuration'][pkgdepends-config]).
 #'
-#' They return a `pkg_download_result` object, which is a data frame
-#' (tibble), that adds extra columns to [`pkg_resolution_result`] (for
+#' They return a `pkg_download_result` object, which is a data frame,
+#' that adds extra columns to [`pkg_resolution_result`] (for
 #' [`pkg_download_proposal`]) or [`pkg_solution_result`]
 #' (for [`pkg_installation_proposal`]):
 #'
@@ -204,7 +204,7 @@ download_ping_if_not_source <- function(resolution, target, config, cache,
     download_one_of(
       resolution$sources[[1]], target, on_progress = on_progress
     )$
-      then(~ "Got")
+      then(function() "Got")
 
   } else if (resolution$platform == "source") {
     ## If it is a source package, then the package name, version number
@@ -213,8 +213,9 @@ download_ping_if_not_source <- function(resolution, target, config, cache,
     cache$package$async_copy_or_add(
       target, resolution$sources[[1]], path = resolution$target,
       package = resolution$package, version = resolution$version,
-      platform = resolution$platform, on_progress = on_progress)$
-    then(~ attr(., "action"))
+      platform = resolution$platform, on_progress = on_progress,
+      http_headers = default_download_headers(resolution$sources[[1]]))$
+    then(function(.) attr(., "action"))
 
   } else {
     ## If not a source package, then we try to update it, in case there is
@@ -222,8 +223,9 @@ download_ping_if_not_source <- function(resolution, target, config, cache,
     cache$package$async_update_or_add(
       target, resolution$sources[[1]], path = resolution$target,
       package = resolution$package, version = resolution$version,
-      platform = resolution$platform, on_progress = on_progress)$
-    then(~ attr(., "action"))
+      platform = resolution$platform, on_progress = on_progress,
+      http_headers = default_download_headers(resolution$sources[[1]]))$
+    then(function(.) attr(., "action"))
   }
 }
 
@@ -238,7 +240,7 @@ download_ping_if_no_sha <- function(resolution, target, config, cache,
     download_one_of(
       resolution$sources[[1]], target, on_progress = on_progress
     )$
-      then(~ "Got")
+      then(function() "Got")
 
   } else  if (! "sha256" %in% names(resolution) || is.na(resolution$sha256)) {
     ## If we don't know the hash of the CRAN package, then just download
@@ -247,8 +249,9 @@ download_ping_if_no_sha <- function(resolution, target, config, cache,
     cache$package$async_copy_or_add(
       target, resolution$sources[[1]], path = resolution$target,
       package = resolution$package, version = resolution$version,
-      platform = resolution$platform, on_progress = on_progress)$
-    then(~ attr(., "action"))
+      platform = resolution$platform, on_progress = on_progress,
+      http_headers = default_download_headers(resolution$sources[[1]]))$
+    then(function(.) attr(., "action"))
 
   } else {
     ## There is a sha hash in the metadata, so we can search for that
@@ -257,8 +260,9 @@ download_ping_if_no_sha <- function(resolution, target, config, cache,
       target, resolution$sources[[1]], path = resolution$target,
       package = resolution$package, version = resolution$version,
       platform = resolution$platform, sha256 = resolution$sha256,
-      on_progress = on_progress)$
-    then(~ attr(., "action"))
+      on_progress = on_progress,
+      http_headers = default_download_headers(resolution$sources[[1]]))$
+    then(function(.) attr(., "action"))
   }
 }
 
@@ -284,3 +288,9 @@ type_default_download <- function(resolution, target, config, cache,
   ## TODO
   stop("Not implemented yet")
 }
+
+default_download_headers <- function(url) {
+  if (any(grepl("^https://ghcr.io", url))) {
+    c("Authorization" = "Bearer QQ==")
+  }
+}
